@@ -1,9 +1,15 @@
 import json
 import pathlib
 import sys
+import os
+dir_path = os.path.dirname(os.path.realpath(__file__))
 
-HERE = pathlib.Path(__file__).parent
+HERE = pathlib.Path(__file__)
+ANIMALS = dir_path+os.sep+'animals.json'
+with open(ANIMALS) as f:
+    CORPUS = json.load(f)
 
+"""
 py_version = sys.version_info
 if py_version.major >= 3 and py_version.minor >= 6:     # Python version >= 3.6
     with open(HERE / "animals.json") as f:
@@ -11,6 +17,7 @@ if py_version.major >= 3 and py_version.minor >= 6:     # Python version >= 3.6
 else:                                                   # Python version < 3.6
     with open(str(HERE / "animals.json")) as f:
         CORPUS = json.load(f)
+"""
 
 BCORPUS = dict( [ (k.encode('ascii'),v) for k,v in CORPUS.items() ])
 
